commit 8550e5b3cff4edda62016aa9fcc1b197798316a7
Author: Richard Kimberly Heck <[email protected]>
Date:   Fri May 16 13:54:33 2025 -0400

    Fix bug #13187
    
    No status entry needed, since this was never released.
    
    (cherry picked from commit d8da6760bcd4329a87717492446a868456173991)
---
 src/frontends/qt/GuiApplication.cpp | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/frontends/qt/GuiApplication.cpp 
b/src/frontends/qt/GuiApplication.cpp
index 3c62f90ce1..6d7b820360 100644
--- a/src/frontends/qt/GuiApplication.cpp
+++ b/src/frontends/qt/GuiApplication.cpp
@@ -2636,8 +2636,9 @@ void GuiApplication::createView(QString const & 
geometry_arg, bool autoShow,
                d->global_menubar_->releaseKeyboard();
 
        // need to reset system input method coords with the preserved one
-       // when the new view is the second one or later
-       if (d->views_.size() > 0)
+       // when the new view is the second one or later and a document is
+       // open in the current view
+       if (d->views_.size() > 0 && current_view_->currentWorkArea())
                current_view_->currentWorkArea()->resetInputItemGeometry(true);
 
        // create new view
-- 
lyx-cvs mailing list
[email protected]
https://lists.lyx.org/mailman/listinfo/lyx-cvs

Reply via email to